@@ -160,7 +160,7 @@ void MainWindow::BmePropertyModifiedSlot(QDBusMessage)
     }
 
     if (temperature > 100)
-        temperature = temperature / 100.0;
+        temperature = temperature / 10.0;
     qDebug() << "Battery temperature: " << temperature;
     ui->lblTemp->setText(QString("%1C").arg(QString::number(temperature, 'f', 1)));
 
@@ -342,10 +342,15 @@ void MainWindow::ProgressBarValueSlot(int value)
 void MainWindow::ApplySettings()
 {
     if (CommonStatic::CurrentSettings->PercStyle == Settings::StyleGraphical){        
+        QSize bkgSize(166, 98);
+        bkgSize.scale(166*CommonStatic::CurrentSettings->PercScale, 98*CommonStatic::CurrentSettings->PercScale, Qt::KeepAspectRatio);
+
         ui->lblPerc->setVisible(false);
         ui->frame->setVisible(true);
-        ui->frame->setFixedSize(166, 98);
-        ui->frame->setStyleSheet("QFrame { background-image: url(:/images/battery.png); }");
+
+        qDebug() << "Percentage size:" << bkgSize.width() << "x" << bkgSize.height();
+        ui->frame->setFixedSize(bkgSize);
+        ui->frame->setStyleSheet("QFrame { border-image: url(:/images/battery.png); }");
         ui->frame->layout()->setContentsMargins(8, 8, 16, 8);
     }else if (CommonStatic::CurrentSettings->PercStyle == Settings::StyleStandard){
         ui->lblPerc->setVisible(false);
